import React, { useRef, useState } from 'react';
import { transcribeAudio } from '../services/whisperApi';
import './AudioRecorder.css';

const AudioRecorder = ({ onTranscriptionComplete }) => {
  const [isRecording, setIsRecording] = useState(false);
  const [error, setError] = useState('');
  const mediaRecorderRef = useRef(null);
  const chunksRef = useRef([]);

  const handleToggleRecording = async () => {
    if (!isRecording) {
      // Start recording
      setError('');
      try {
        const stream = await navigator.mediaDevices.getUserMedia({ audio: true });
        mediaRecorderRef.current = new MediaRecorder(stream);
        chunksRef.current = [];

        mediaRecorderRef.current.ondataavailable = (e) => {
          if (e.data.size > 0) {
            chunksRef.current.push(e.data);
          }
        };

        mediaRecorderRef.current.onstop = async () => {
          const audioBlob = new Blob(chunksRef.current, { type: 'audio/webm' });
          try {
            const transcribedText = await transcribeAudio(audioBlob);
            onTranscriptionComplete(transcribedText);
          } catch (err) {
            setError('Transcription failed: ' + err.message);
            console.error('Transcription error:', err);
          }
        };

        mediaRecorderRef.current.start();
        setIsRecording(true);
      } catch (err) {
        setError('Microphone access error: ' + err.message);
        console.error('Microphone error:', err);
      }
    } else {
      // Stop recording
      mediaRecorderRef.current.stop();
      setIsRecording(false);
      // Stop all tracks in the stream
      mediaRecorderRef.current.stream.getTracks().forEach(track => track.stop());
    }
  };

  return (
    <div className="audio-recorder">
      <button 
        className={`record-button ${isRecording ? 'recording' : ''}`}
        onClick={handleToggleRecording}
      >
        {isRecording ? 'Stop' : 'Record'}
      </button>
      {error && <p className="error-message">{error}</p>}
    </div>
  );
};

export default AudioRecorder;

